part of '../../ngx_core.dart';

/// Provides a set of media queries adhering to the [Material Design specification](https://material.io/design/layout/responsive-layout-grid.html#breakpoints).
abstract class Breakpoints {
  /// The breakpoint corresponding to an extra small window.
  static const String xSmall = '(max-width: 599.99px)';

  /// The breakpoint corresponding to a small window.
  static const String small = '(min-width: 600px) and (max-width: 959.99px)';

  /// The breakpoint corresponding to a medium window.
  static const String medium = '(min-width: 960px) and (max-width: 1279.99px)';

  /// The breakpoint corresponding to a large window.
  static const String large = '(min-width: 1280px) and (max-width: 1919.99px)';

  /// The breakpoint corresponding to an extra large window.
  static const String xLarge = '(min-width: 1920px)';

  /// The breakpoint corresponding to an handset.
  static const String handset = '$handsetLandscape, $handsetPortrait';

  /// The breakpoint corresponding to an handset in landscape orientation.
  static const String handsetLandscape =
      '(max-width: 959.99px) and (orientation: landscape)';

  /// The breakpoint corresponding to an handset in portrait orientation.
  static const String handsetPortrait =
      '(max-width: 599.99px) and (orientation: portrait)';

  /// The breakpoint corresponding to a tablet.
  static const String tablet = '$tabletLandscape, $tabletPortrait';

  /// The breakpoint corresponding to a tablet in landscape orientation.
  static const String tabletLandscape =
      '(min-width: 960px) and (max-width: 1279.99px) and (orientation: landscape)';

  /// The breakpoint corresponding to a tablet in portrait orientation.
  static const String tabletPortrait =
      '(min-width: 600px) and (max-width: 839.99px) and (orientation: portrait)';

  /// The breakpoint corresponding to a large device.
  static const String web = '$webLandscape, $webPortrait';

  /// The breakpoint corresponding to a large device in landscape orientation.
  static const String webLandscape =
      '(min-width: 1280px) and (orientation: landscape)';

  /// The breakpoint corresponding to a large device in portrait orientation.
  static const String webPortrait =
      '(min-width: 840px) and (orientation: portrait)';
}
