part of '../../ngx_core.dart';

/// The start date of the Unix time.
final DateTime _epoch = DateTime.fromMillisecondsSinceEpoch(0, isUtc: true);

/// An interface that should be implemented by classes providing identity information.
abstract class Identity {
  /// A key that can be used to check the validity of this identity.
  String authKey;

  /// An identifier that can uniquely identify a user identity.
  dynamic get id;
}

/// Exception thrown when the authentication data processed by a session is invalid.
class SessionException implements Exception {
  /// Creates a new session error.
  const SessionException([this.message]);

  /// A message describing the session error.
  final String message;
}

/// Represents an access token.
class SessionToken {
  /// Creates a new session token.
  SessionToken([this.value = '', DateTime expires])
      : expires = expires ?? _epoch;

  /// Creates a new session token from the specified [map] in JSON format.
  SessionToken.fromJson(Map<String, dynamic> map)
      : expires = map['expires'] is String
            ? DateTime.tryParse(map['expires']) ?? _epoch
            : _epoch,
        value = map['value'] is String ? map['value'] : '';

  /// The expiration date and time for the token.
  DateTime expires;

  /// Value indicating if this session token is valid.
  bool get isValid => value.isNotEmpty && expires.isAfter(DateTime.now());

  /// The authentication key.
  final String value;

  /// Converts this object to a [Map] in JSON format.
  Map<String, dynamic> toJson() =>
      <String, dynamic>{'expires': expires.toIso8601String(), 'value': value};
}
