import 'package:ngx_core/ngx_core.dart';
import 'package:test/test.dart';

/// Tests the features of the [SessionToken] class.
void main() => group('SessionToken', () {
      group('.isValid', () {
        test('should be `false` is the token is expired', () {
          final token = SessionToken(
              'foo', DateTime.fromMillisecondsSinceEpoch(0, isUtc: true));
          expect(token.isValid, isFalse);
        });

        test('should be `false` is the token is empty', () {
          final token =
              SessionToken('', DateTime.now().add(Duration(minutes: 10)));
          expect(token.isValid, isFalse);
        });

        test('should be `true` is the token is valid', () {
          final token =
              SessionToken('foo', DateTime.now().add(Duration(minutes: 10)));
          expect(token.isValid, isTrue);
        });
      });

      group('.fromJson()', () {
        test('should return an instance with default values for an empty map',
            () {
          final token = SessionToken.fromJson(<String, dynamic>{});
          expect(token.expires,
              DateTime.fromMillisecondsSinceEpoch(0, isUtc: true));
          expect(token.value, isEmpty);
        });

        test('should return an initialized instance for a non-empty map', () {
          final token = SessionToken.fromJson(<String, dynamic>{
            'expires': '2020-12-31T12:30:00.000Z',
            'value': 'foo'
          });

          expect(token.expires, DateTime.utc(2020, 12, 31, 12, 30));
          expect(token.value, 'foo');
        });
      });

      group('.toJson()', () {
        test(
            'should return a map with default values for a newly created instance',
            () {
          final map = SessionToken().toJson();
          expect(map, hasLength(2));
          expect(map['expires'], '1970-01-01T00:00:00.000Z');
          expect(map['value'], isEmpty);
        });

        test('should return a non-empty map for an initialized instance', () {
          final map =
              SessionToken('foo', DateTime.utc(2020, 12, 31, 12, 30)).toJson();
          expect(map, hasLength(2));
          expect(map['expires'], '2020-12-31T12:30:00.000Z');
          expect(map['value'], 'foo');
        });
      });
    });
